# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from ydb._grpc.v3.protos import ydb_operation_pb2 as protos_dot_ydb__operation__pb2
from ydb._grpc.v3.protos import ydb_query_pb2 as protos_dot_ydb__query__pb2


class QueryServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateSession = channel.unary_unary(
                '/Ydb.Query.V1.QueryService/CreateSession',
                request_serializer=protos_dot_ydb__query__pb2.CreateSessionRequest.SerializeToString,
                response_deserializer=protos_dot_ydb__query__pb2.CreateSessionResponse.FromString,
                )
        self.DeleteSession = channel.unary_unary(
                '/Ydb.Query.V1.QueryService/DeleteSession',
                request_serializer=protos_dot_ydb__query__pb2.DeleteSessionRequest.SerializeToString,
                response_deserializer=protos_dot_ydb__query__pb2.DeleteSessionResponse.FromString,
                )
        self.AttachSession = channel.unary_stream(
                '/Ydb.Query.V1.QueryService/AttachSession',
                request_serializer=protos_dot_ydb__query__pb2.AttachSessionRequest.SerializeToString,
                response_deserializer=protos_dot_ydb__query__pb2.SessionState.FromString,
                )
        self.BeginTransaction = channel.unary_unary(
                '/Ydb.Query.V1.QueryService/BeginTransaction',
                request_serializer=protos_dot_ydb__query__pb2.BeginTransactionRequest.SerializeToString,
                response_deserializer=protos_dot_ydb__query__pb2.BeginTransactionResponse.FromString,
                )
        self.CommitTransaction = channel.unary_unary(
                '/Ydb.Query.V1.QueryService/CommitTransaction',
                request_serializer=protos_dot_ydb__query__pb2.CommitTransactionRequest.SerializeToString,
                response_deserializer=protos_dot_ydb__query__pb2.CommitTransactionResponse.FromString,
                )
        self.RollbackTransaction = channel.unary_unary(
                '/Ydb.Query.V1.QueryService/RollbackTransaction',
                request_serializer=protos_dot_ydb__query__pb2.RollbackTransactionRequest.SerializeToString,
                response_deserializer=protos_dot_ydb__query__pb2.RollbackTransactionResponse.FromString,
                )
        self.ExecuteQuery = channel.unary_stream(
                '/Ydb.Query.V1.QueryService/ExecuteQuery',
                request_serializer=protos_dot_ydb__query__pb2.ExecuteQueryRequest.SerializeToString,
                response_deserializer=protos_dot_ydb__query__pb2.ExecuteQueryResponsePart.FromString,
                )
        self.ExecuteScript = channel.unary_unary(
                '/Ydb.Query.V1.QueryService/ExecuteScript',
                request_serializer=protos_dot_ydb__query__pb2.ExecuteScriptRequest.SerializeToString,
                response_deserializer=protos_dot_ydb__operation__pb2.Operation.FromString,
                )
        self.FetchScriptResults = channel.unary_unary(
                '/Ydb.Query.V1.QueryService/FetchScriptResults',
                request_serializer=protos_dot_ydb__query__pb2.FetchScriptResultsRequest.SerializeToString,
                response_deserializer=protos_dot_ydb__query__pb2.FetchScriptResultsResponse.FromString,
                )


class QueryServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def CreateSession(self, request, context):
        """Sessions are basic primitives for communicating with YDB Query Service. The are similar to
        connections for classic relational DBs. Sessions serve three main purposes:
        1. Provide a flow control for DB requests with limited number of active channels.
        2. Distribute load evenly across multiple DB nodes.
        3. Store state for volatile stateful operations, such as short-living transactions.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteSession(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AttachSession(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BeginTransaction(self, request, context):
        """Short-living transactions allow transactional execution of several queries, including support
        for interactive transactions. Transaction control can be implemented via flags in ExecuteQuery
        call (recommended), or via explicit calls to Begin/Commit/RollbackTransaction.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CommitTransaction(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RollbackTransaction(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ExecuteQuery(self, request, context):
        """Execute interactive query in a specified short-living transaction.
        YDB query can contain DML, DDL and DCL statements. Supported mix of different statement types depends
        on the chosen transaction type.
        In case of error, including transport errors such as interrupted stream, whole transaction
        needs to be retried. For non-idempotent transaction, a custom client logic is required to
        retry conditionally retriable statuses, when transaction execution state is unknown.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ExecuteScript(self, request, context):
        """Execute long-running script.
        YDB scripts can contain all type of statements, including TCL statements. This way you can execute multiple
        transactions in a single YDB script.
        ExecuteScript call returns long-running Ydb.Operation object with:
        operation.metadata = ExecuteScriptMetadata
        operation.result = Empty
        Script execution metadata contains all information about current execution state, including
        execution_id, execution statistics and result sets info.
        You can use standard operation methods such as Get/Cancel/Forget/ListOperations to work with script executions.
        Script can be executed as persistent, in which case all execution information and results will be stored
        persistently and available after successful or unsuccessful execution.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def FetchScriptResults(self, request, context):
        """Fetch results for script execution using fetch_token for continuation.
        For script with multiple result sets, parts of different results sets are interleaved in responses.
        For persistent scripts, you can fetch results in specific position of specific result set using
        position instead of fetch_token.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_QueryServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateSession': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateSession,
                    request_deserializer=protos_dot_ydb__query__pb2.CreateSessionRequest.FromString,
                    response_serializer=protos_dot_ydb__query__pb2.CreateSessionResponse.SerializeToString,
            ),
            'DeleteSession': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteSession,
                    request_deserializer=protos_dot_ydb__query__pb2.DeleteSessionRequest.FromString,
                    response_serializer=protos_dot_ydb__query__pb2.DeleteSessionResponse.SerializeToString,
            ),
            'AttachSession': grpc.unary_stream_rpc_method_handler(
                    servicer.AttachSession,
                    request_deserializer=protos_dot_ydb__query__pb2.AttachSessionRequest.FromString,
                    response_serializer=protos_dot_ydb__query__pb2.SessionState.SerializeToString,
            ),
            'BeginTransaction': grpc.unary_unary_rpc_method_handler(
                    servicer.BeginTransaction,
                    request_deserializer=protos_dot_ydb__query__pb2.BeginTransactionRequest.FromString,
                    response_serializer=protos_dot_ydb__query__pb2.BeginTransactionResponse.SerializeToString,
            ),
            'CommitTransaction': grpc.unary_unary_rpc_method_handler(
                    servicer.CommitTransaction,
                    request_deserializer=protos_dot_ydb__query__pb2.CommitTransactionRequest.FromString,
                    response_serializer=protos_dot_ydb__query__pb2.CommitTransactionResponse.SerializeToString,
            ),
            'RollbackTransaction': grpc.unary_unary_rpc_method_handler(
                    servicer.RollbackTransaction,
                    request_deserializer=protos_dot_ydb__query__pb2.RollbackTransactionRequest.FromString,
                    response_serializer=protos_dot_ydb__query__pb2.RollbackTransactionResponse.SerializeToString,
            ),
            'ExecuteQuery': grpc.unary_stream_rpc_method_handler(
                    servicer.ExecuteQuery,
                    request_deserializer=protos_dot_ydb__query__pb2.ExecuteQueryRequest.FromString,
                    response_serializer=protos_dot_ydb__query__pb2.ExecuteQueryResponsePart.SerializeToString,
            ),
            'ExecuteScript': grpc.unary_unary_rpc_method_handler(
                    servicer.ExecuteScript,
                    request_deserializer=protos_dot_ydb__query__pb2.ExecuteScriptRequest.FromString,
                    response_serializer=protos_dot_ydb__operation__pb2.Operation.SerializeToString,
            ),
            'FetchScriptResults': grpc.unary_unary_rpc_method_handler(
                    servicer.FetchScriptResults,
                    request_deserializer=protos_dot_ydb__query__pb2.FetchScriptResultsRequest.FromString,
                    response_serializer=protos_dot_ydb__query__pb2.FetchScriptResultsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'Ydb.Query.V1.QueryService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class QueryService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def CreateSession(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Ydb.Query.V1.QueryService/CreateSession',
            protos_dot_ydb__query__pb2.CreateSessionRequest.SerializeToString,
            protos_dot_ydb__query__pb2.CreateSessionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteSession(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Ydb.Query.V1.QueryService/DeleteSession',
            protos_dot_ydb__query__pb2.DeleteSessionRequest.SerializeToString,
            protos_dot_ydb__query__pb2.DeleteSessionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AttachSession(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/Ydb.Query.V1.QueryService/AttachSession',
            protos_dot_ydb__query__pb2.AttachSessionRequest.SerializeToString,
            protos_dot_ydb__query__pb2.SessionState.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def BeginTransaction(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Ydb.Query.V1.QueryService/BeginTransaction',
            protos_dot_ydb__query__pb2.BeginTransactionRequest.SerializeToString,
            protos_dot_ydb__query__pb2.BeginTransactionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CommitTransaction(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Ydb.Query.V1.QueryService/CommitTransaction',
            protos_dot_ydb__query__pb2.CommitTransactionRequest.SerializeToString,
            protos_dot_ydb__query__pb2.CommitTransactionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RollbackTransaction(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Ydb.Query.V1.QueryService/RollbackTransaction',
            protos_dot_ydb__query__pb2.RollbackTransactionRequest.SerializeToString,
            protos_dot_ydb__query__pb2.RollbackTransactionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ExecuteQuery(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/Ydb.Query.V1.QueryService/ExecuteQuery',
            protos_dot_ydb__query__pb2.ExecuteQueryRequest.SerializeToString,
            protos_dot_ydb__query__pb2.ExecuteQueryResponsePart.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ExecuteScript(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Ydb.Query.V1.QueryService/ExecuteScript',
            protos_dot_ydb__query__pb2.ExecuteScriptRequest.SerializeToString,
            protos_dot_ydb__operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def FetchScriptResults(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Ydb.Query.V1.QueryService/FetchScriptResults',
            protos_dot_ydb__query__pb2.FetchScriptResultsRequest.SerializeToString,
            protos_dot_ydb__query__pb2.FetchScriptResultsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



import logging
import asyncio
import typing
from typing import Any, Tuple, Callable, Iterable
import collections
import grpc

from ydb import _apis, _utilities

from ydb.connection import (
    _log_request,
    _log_response,
    _rpc_error_handler,
    _is_disconnect_needed,
    _get_request_timeout,
    _set_server_timeouts,
    _RpcState as RpcState,
    EndpointOptions,
    channel_factory,
    YDB_DATABASE_HEADER,
    YDB_TRACE_ID_HEADER,
    YDB_REQUEST_TYPE_HEADER,
    EndpointKey,
)
from ydb.driver import DriverConfig
from ydb.settings import BaseRequestSettings
from ydb import issues

# Workaround for good IDE and universal for runtime
if typing.TYPE_CHECKING:
    from ydb._grpc.v4 import ydb_topic_v1_pb2_grpc
else:
    from ydb._grpc.common import ydb_topic_v1_pb2_grpc


_stubs_list = (
    _apis.TableService.Stub,
    _apis.SchemeService.Stub,
    _apis.DiscoveryService.Stub,
    _apis.CmsService.Stub,
    ydb_topic_v1_pb2_grpc.TopicServiceStub,
)
logger = logging.getLogger(__name__)


async def _construct_metadata(driver_config, settings):
    """
    Translates request settings into RPC metadata
    :param driver_config: A driver config
    :param settings: An instance of BaseRequestSettings
    :return: RPC metadata
    """
    metadata = []
    if driver_config.database is not None:
        metadata.append((YDB_DATABASE_HEADER, driver_config.database))

    if driver_config.credentials is not None:
        res = driver_config.credentials.auth_metadata()
        if asyncio.iscoroutine(res):
            res = await res
        metadata.extend(res)

    if settings is not None:
        if settings.trace_id is not None:
            metadata.append((YDB_TRACE_ID_HEADER, settings.trace_id))
        if settings.request_type is not None:
            metadata.append((YDB_REQUEST_TYPE_HEADER, settings.request_type))

    metadata.append(_utilities.x_ydb_sdk_build_info_header())
    return metadata


class _RpcState(RpcState):
    __slots__ = (
        "rpc",
        "request_id",
        "rendezvous",
        "result_future",
        "rpc_name",
        "endpoint",
        "metadata_kv",
        "_trailing_metadata",
    )

    def __init__(self, stub_instance: Any, rpc_name: str, endpoint: str, endpoint_key):
        super().__init__(stub_instance, rpc_name, endpoint, endpoint_key)

    async def __call__(self, *args, **kwargs):
        resp = self.rpc(*args, **kwargs)
        if hasattr(resp, "__await__"):  # Check to support async iterators from streams
            response = await resp
            self._trailing_metadata = await resp.trailing_metadata()
            return response
        return resp

    def trailing_metadata(self):
        if self.metadata_kv is None:
            self.metadata_kv = collections.defaultdict(set)
            for key, value in self._trailing_metadata:
                self.metadata_kv[key].add(value)
        return self.metadata_kv

    def future(self, *args, **kwargs):
        raise NotImplementedError


class _SafeAsyncIterator:
    def __init__(self, resp, rpc_state, on_disconnected_callback):
        self.resp = resp
        self.it = resp.__aiter__()
        self.rpc_state = rpc_state
        self.on_disconnected_callback = on_disconnected_callback

    def cancel(self):
        self.resp.cancel()
        return self

    def __aiter__(self):
        return self

    async def __anext__(self):
        try:
            return await self.it.__anext__()
        except grpc.RpcError as rpc_error:
            ydb_error = _rpc_error_handler(self.rpc_state, rpc_error, use_unavailable=True)
            if _is_disconnect_needed(ydb_error):
                await self.on_disconnected_callback()
            raise ydb_error

    def __getattr__(self, item):
        return getattr(self.resp, item)


class Connection:
    __slots__ = (
        "endpoint",
        "_channel",
        "_call_states",
        "_stub_instances",
        "_driver_config",
        "_cleanup_callbacks",
        "__weakref__",
        "lock",
        "calls",
        "closing",
        "endpoint_key",
        "node_id",
    )

    def __init__(
        self,
        endpoint: str,
        driver_config: DriverConfig = None,
        endpoint_options: EndpointOptions = None,
    ):
        global _stubs_list
        self.endpoint = endpoint
        self.endpoint_key = EndpointKey(self.endpoint, getattr(endpoint_options, "node_id", None))
        self.node_id = getattr(endpoint_options, "node_id", None)
        self._channel = channel_factory(self.endpoint, driver_config, grpc.aio, endpoint_options=endpoint_options)
        self._driver_config = driver_config

        self._stub_instances = {}
        self._cleanup_callbacks = []
        for stub in _stubs_list:
            self._stub_instances[stub] = stub(self._channel)

        self.calls = {}
        self.closing = False

    def _prepare_stub_instance(self, stub: Any):
        if stub not in self._stub_instances:
            self._stub_instances[stub] = stub(self._channel)

    async def _prepare_call(
        self, stub: Any, rpc_name: str, request: Any, settings: BaseRequestSettings
    ) -> Tuple[_RpcState, float, Any]:

        timeout, metadata = _get_request_timeout(settings), await _construct_metadata(self._driver_config, settings)
        _set_server_timeouts(request, settings, timeout)
        self._prepare_stub_instance(stub)
        rpc_state = _RpcState(self._stub_instances[stub], rpc_name, self.endpoint, self.endpoint_key)
        logger.debug("%s: creating call state", rpc_state)

        if self.closing:
            raise issues.ConnectionLost("Couldn't start call")

        # Call successfully prepared and registered
        _log_request(rpc_state, request)
        return rpc_state, timeout, metadata

    async def __call__(
        self,
        request: Any,
        stub: Any,
        rpc_name: str,
        wrap_result: Callable = None,
        settings: BaseRequestSettings = None,
        wrap_args: Iterable = (),
        on_disconnected: Callable = None,
    ) -> Any:
        """
        Async method to execute request
        :param request:  A request constructed by client
        :param stub:  A stub instance to wrap channel
        :param rpc_name: A name of RPC to be executed
        :param wrap_result: A callable that intercepts call and wraps received response
        :param settings: An instance of BaseRequestSettings that can be used
        for RPC metadata construction
        :param on_disconnected: A callable to be executed when underlying channel becomes disconnected
        :param wrap_args: And arguments to be passed into wrap_result callable
        :return: A result of computation
        """
        rpc_state, timeout, metadata = await self._prepare_call(stub, rpc_name, request, settings)
        try:
            feature = asyncio.ensure_future(rpc_state(request, timeout=timeout, metadata=metadata))

            # Add feature to dict to wait until it finished when close called
            self.calls[rpc_state.request_id] = feature

            response = await feature
            _log_response(rpc_state, response)

            if hasattr(response, "__aiter__"):
                # NOTE(vgvoleg): for stream results we should also be able to handle disconnects
                response = _SafeAsyncIterator(response, rpc_state, on_disconnected)

            return response if wrap_result is None else wrap_result(rpc_state, response, *wrap_args)
        except grpc.RpcError as rpc_error:
            if on_disconnected:
                coro = on_disconnected()
                if asyncio.iscoroutine(coro):
                    await coro
                on_disconnected = None
            raise _rpc_error_handler(rpc_state, rpc_error, on_disconnected)
        finally:
            self._finish_call(rpc_state)

    def _finish_call(self, call_state: _RpcState):
        self.calls.pop(call_state.request_id)

    async def destroy(self, grace: float = 0):
        """
        Destroys the underlying gRPC channel
        This method does not cancel tasks, but destroys them.
        :param grace:
        :return: None
        """
        if hasattr(self, "_channel") and hasattr(self._channel, "close"):
            await self._channel.close(grace)

    def add_cleanup_callback(self, callback):
        self._cleanup_callbacks.append(callback)

    async def connection_ready(self, ready_timeout=10):
        """
        Awaits until channel is ready
        :return: None
        """

        await asyncio.wait_for(self._channel.channel_ready(), timeout=ready_timeout)

    async def close(self, grace: float = 30):
        """
        Closes the underlying gRPC channel
        :param: grace: If a grace period is specified, this method wait until all active
        RPCs are finshed, once the grace period is reached the ones that haven't
        been terminated are cancelled. If grace is None, this method will wait until all tasks are finished.
        :return: None
        """
        logger.debug("Closing channel for endpoint %s", self.endpoint)

        self.closing = True

        for callback in self._cleanup_callbacks:
            callback(self)

        if self.calls:
            await asyncio.wait(self.calls.values(), timeout=grace)

        await self.destroy()

    async def __aenter__(self):
        return self

    async def __aexit__(self, exc_type, exc_val, exc_tb):
        await self.close()



# -*- coding: utf-8 -*-
# flake8: noqa
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: draft/protos/ydb_maintenance.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb._grpc.v3.protos.annotations import validation_pb2 as protos_dot_annotations_dot_validation__pb2
from ydb._grpc.v3.protos import ydb_status_codes_pb2 as protos_dot_ydb__status__codes__pb2
from ydb._grpc.v3.protos import ydb_discovery_pb2 as protos_dot_ydb__discovery__pb2
from ydb._grpc.v3.protos import ydb_operation_pb2 as protos_dot_ydb__operation__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='draft/protos/ydb_maintenance.proto',
  package='Ydb.Maintenance',
  syntax='proto3',
  serialized_options=b'\n#tech.ydb.proto.draft.maintenance.v1ZDgithub.com/ydb-platform/ydb-go-genproto/draft/protos/Ydb_Maintenance\370\001\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\"draft/protos/ydb_maintenance.proto\x12\x0fYdb.Maintenance\x1a#protos/annotations/validation.proto\x1a\x1dprotos/ydb_status_codes.proto\x1a\x1aprotos/ydb_discovery.proto\x1a\x1aprotos/ydb_operation.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xf0\x02\n\x04Node\x12\x0f\n\x07node_id\x18\x01 \x01(\r\x12\x0c\n\x04host\x18\x02 \x01(\t\x12\x0c\n\x04port\x18\x03 \x01(\r\x12-\n\x08location\x18\x04 \x01(\x0b\x32\x1b.Ydb.Discovery.NodeLocation\x12)\n\x05state\x18\x05 \x01(\x0e\x32\x1a.Ydb.Maintenance.ItemState\x12\x34\n\x07storage\x18\x06 \x01(\x0b\x32!.Ydb.Maintenance.Node.StorageNodeH\x00\x12\x34\n\x07\x64ynamic\x18\x07 \x01(\x0b\x32!.Ydb.Maintenance.Node.DynamicNodeH\x00\x12.\n\nstart_time\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0f\n\x07version\x18\t \x01(\t\x1a\r\n\x0bStorageNode\x1a\x1d\n\x0b\x44ynamicNode\x12\x0e\n\x06tenant\x18\x01 \x01(\tB\x06\n\x04type\"T\n\x17ListClusterNodesRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\">\n\x16ListClusterNodesResult\x12$\n\x05nodes\x18\x01 \x03(\x0b\x32\x15.Ydb.Maintenance.Node\"H\n\x18ListClusterNodesResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\xc3\x01\n\x16MaintenanceTaskOptions\x12\x19\n\x08task_uid\x18\x01 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x01\x12\x1c\n\x0b\x64\x65scription\x18\x02 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x01\x12<\n\x11\x61vailability_mode\x18\x03 \x01(\x0e\x32!.Ydb.Maintenance.AvailabilityMode\x12\x0f\n\x07\x64ry_run\x18\x04 \x01(\x08\x12!\n\x08priority\x18\x05 \x01(\x05\x42\x0f\xb2\xe6*\x0b[-100; 100]\"B\n\x0b\x41\x63tionScope\x12\x11\n\x07node_id\x18\x01 \x01(\rH\x00\x12\x17\n\x04host\x18\x02 \x01(\tB\x07\xa2\xe6*\x03\x18\xff\x01H\x00\x42\x07\n\x05scope\"f\n\nLockAction\x12+\n\x05scope\x18\x01 \x01(\x0b\x32\x1c.Ydb.Maintenance.ActionScope\x12+\n\x08\x64uration\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\"F\n\x06\x41\x63tion\x12\x32\n\x0block_action\x18\x01 \x01(\x0b\x32\x1b.Ydb.Maintenance.LockActionH\x00\x42\x08\n\x06\x61\x63tion\"?\n\x0b\x41\x63tionGroup\x12\x30\n\x07\x61\x63tions\x18\x01 \x03(\x0b\x32\x17.Ydb.Maintenance.ActionB\x06\x9a\xe6*\x02(\x01\"\xd5\x01\n\x1c\x43reateMaintenanceTaskRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12=\n\x0ctask_options\x18\x02 \x01(\x0b\x32\'.Ydb.Maintenance.MaintenanceTaskOptions\x12;\n\raction_groups\x18\x03 \x03(\x0b\x32\x1c.Ydb.Maintenance.ActionGroupB\x06\x9a\xe6*\x02(\x01\"u\n\x1dRefreshMaintenanceTaskRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x19\n\x08task_uid\x18\x02 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x01\"]\n\tActionUid\x12\x19\n\x08task_uid\x18\x01 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x01\x12\x19\n\x08group_id\x18\x02 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x01\x12\x1a\n\taction_id\x18\x03 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x01\"\x8f\x06\n\x0b\x41\x63tionState\x12\'\n\x06\x61\x63tion\x18\x01 \x01(\x0b\x32\x17.Ydb.Maintenance.Action\x12.\n\naction_uid\x18\x02 \x01(\x0b\x32\x1a.Ydb.Maintenance.ActionUid\x12\x39\n\x06status\x18\x03 \x01(\x0e\x32).Ydb.Maintenance.ActionState.ActionStatus\x12\x39\n\x06reason\x18\x04 \x01(\x0e\x32).Ydb.Maintenance.ActionState.ActionReason\x12\x16\n\x0ereason_details\x18\x06 \x01(\t\x12,\n\x08\x64\x65\x61\x64line\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"e\n\x0c\x41\x63tionStatus\x12\x1d\n\x19\x41\x43TION_STATUS_UNSPECIFIED\x10\x00\x12\x19\n\x15\x41\x43TION_STATUS_PENDING\x10\x01\x12\x1b\n\x17\x41\x43TION_STATUS_PERFORMED\x10\x02\"\x83\x03\n\x0c\x41\x63tionReason\x12\x1d\n\x19\x41\x43TION_REASON_UNSPECIFIED\x10\x00\x12\x14\n\x10\x41\x43TION_REASON_OK\x10\x01\x12-\n)ACTION_REASON_TOO_MANY_UNAVAILABLE_VDISKS\x10\x02\x12:\n6ACTION_REASON_TOO_MANY_UNAVAILABLE_STATE_STORAGE_RINGS\x10\x03\x12.\n*ACTION_REASON_DISABLED_NODES_LIMIT_REACHED\x10\x04\x12\x35\n1ACTION_REASON_TENANT_DISABLED_NODES_LIMIT_REACHED\x10\x05\x12\x1f\n\x1b\x41\x43TION_REASON_WRONG_REQUEST\x10\x06\x12\x30\n,ACTION_REASON_SYS_TABLETS_NODE_LIMIT_REACHED\x10\x07\x12\x19\n\x15\x41\x43TION_REASON_GENERIC\x10\x08\"H\n\x11\x41\x63tionGroupStates\x12\x33\n\raction_states\x18\x01 \x03(\x0b\x32\x1c.Ydb.Maintenance.ActionState\"\xb0\x01\n\x15MaintenanceTaskResult\x12\x10\n\x08task_uid\x18\x01 \x01(\t\x12?\n\x13\x61\x63tion_group_states\x18\x02 \x03(\x0b\x32\".Ydb.Maintenance.ActionGroupStates\x12\x34\n\x0bretry_after\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00\x88\x01\x01\x42\x0e\n\x0c_retry_after\"G\n\x17MaintenanceTaskResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"q\n\x19GetMaintenanceTaskRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x19\n\x08task_uid\x18\x02 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x01\"\x9a\x01\n\x18GetMaintenanceTaskResult\x12=\n\x0ctask_options\x18\x01 \x01(\x0b\x32\'.Ydb.Maintenance.MaintenanceTaskOptions\x12?\n\x13\x61\x63tion_group_states\x18\x02 \x03(\x0b\x32\".Ydb.Maintenance.ActionGroupStates\"J\n\x1aGetMaintenanceTaskResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"t\n\x1bListMaintenanceTasksRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x11\n\x04user\x18\x02 \x01(\tH\x00\x88\x01\x01\x42\x07\n\x05_user\"0\n\x1aListMaintenanceTasksResult\x12\x12\n\ntasks_uids\x18\x01 \x03(\t\"L\n\x1cListMaintenanceTasksResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"r\n\x1a\x44ropMaintenanceTaskRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x19\n\x08task_uid\x18\x02 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x01\"M\n\x1dManageMaintenanceTaskResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x8b\x01\n\x15\x43ompleteActionRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x37\n\x0b\x61\x63tion_uids\x18\x02 \x03(\x0b\x32\x1a.Ydb.Maintenance.ActionUidB\x06\x9a\xe6*\x02(\x01\"\xbe\x01\n\x12ManageActionResult\x12\x43\n\x0f\x61\x63tion_statuses\x18\x01 \x03(\x0b\x32*.Ydb.Maintenance.ManageActionResult.Status\x1a\x63\n\x06Status\x12.\n\naction_uid\x18\x01 \x01(\x0b\x32\x1a.Ydb.Maintenance.ActionUid\x12)\n\x06status\x18\x02 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\"D\n\x14ManageActionResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation*k\n\tItemState\x12\x1a\n\x16ITEM_STATE_UNSPECIFIED\x10\x00\x12\x11\n\rITEM_STATE_UP\x10\x01\x12\x1a\n\x16ITEM_STATE_MAINTENANCE\x10\x02\x12\x13\n\x0fITEM_STATE_DOWN\x10\x03*\x8c\x01\n\x10\x41vailabilityMode\x12!\n\x1d\x41VAILABILITY_MODE_UNSPECIFIED\x10\x00\x12\x1c\n\x18\x41VAILABILITY_MODE_STRONG\x10\x01\x12\x1a\n\x16\x41VAILABILITY_MODE_WEAK\x10\x02\x12\x1b\n\x17\x41VAILABILITY_MODE_FORCE\x10\x03\x42n\n#tech.ydb.proto.draft.maintenance.v1ZDgithub.com/ydb-platform/ydb-go-genproto/draft/protos/Ydb_Maintenance\xf8\x01\x01\x62\x06proto3'
  ,
  dependencies=[protos_dot_annotations_dot_validation__pb2.DESCRIPTOR,protos_dot_ydb__status__codes__pb2.DESCRIPTOR,protos_dot_ydb__discovery__pb2.DESCRIPTOR,protos_dot_ydb__operation__pb2.DESCRIPTOR,google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])

_ITEMSTATE = _descriptor.EnumDescriptor(
  name='ItemState',
  full_name='Ydb.Maintenance.ItemState',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ITEM_STATE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ITEM_STATE_UP', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ITEM_STATE_MAINTENANCE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ITEM_STATE_DOWN', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4082,
  serialized_end=4189,
)
_sym_db.RegisterEnumDescriptor(_ITEMSTATE)

ItemState = enum_type_wrapper.EnumTypeWrapper(_ITEMSTATE)
_AVAILABILITYMODE = _descriptor.EnumDescriptor(
  name='AvailabilityMode',
  full_name='Ydb.Maintenance.AvailabilityMode',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='AVAILABILITY_MODE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='AVAILABILITY_MODE_STRONG', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='AVAILABILITY_MODE_WEAK', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='AVAILABILITY_MODE_FORCE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4192,
  serialized_end=4332,
)
_sym_db.RegisterEnumDescriptor(_AVAILABILITYMODE)

AvailabilityMode = enum_type_wrapper.EnumTypeWrapper(_AVAILABILITYMODE)
ITEM_STATE_UNSPECIFIED = 0
ITEM_STATE_UP = 1
ITEM_STATE_MAINTENANCE = 2
ITEM_STATE_DOWN = 3
AVAILABILITY_MODE_UNSPECIFIED = 0
AVAILABILITY_MODE_STRONG = 1
AVAILABILITY_MODE_WEAK = 2
AVAILABILITY_MODE_FORCE = 3


_ACTIONSTATE_ACTIONSTATUS = _descriptor.EnumDescriptor(
  name='ActionStatus',
  full_name='Ydb.Maintenance.ActionState.ActionStatus',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ACTION_STATUS_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ACTION_STATUS_PENDING', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ACTION_STATUS_PERFORMED', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2069,
  serialized_end=2170,
)
_sym_db.RegisterEnumDescriptor(_ACTIONSTATE_ACTIONSTATUS)

_ACTIONSTATE_ACTIONREASON = _descriptor.EnumDescriptor(
  name='ActionReason',
  full_name='Ydb.Maintenance.ActionState.ActionReason',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ACTION_REASON_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ACTION_REASON_OK', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ACTION_REASON_TOO_MANY_UNAVAILABLE_VDISKS', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ACTION_REASON_TOO_MANY_UNAVAILABLE_STATE_STORAGE_RINGS', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ACTION_REASON_DISABLED_NODES_LIMIT_REACHED', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ACTION_REASON_TENANT_DISABLED_NODES_LIMIT_REACHED', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ACTION_REASON_WRONG_REQUEST', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ACTION_REASON_SYS_TABLETS_NODE_LIMIT_REACHED', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ACTION_REASON_GENERIC', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2173,
  serialized_end=2560,
)
_sym_db.RegisterEnumDescriptor(_ACTIONSTATE_ACTIONREASON)


_NODE_STORAGENODE = _descriptor.Descriptor(
  name='StorageNode',
  full_name='Ydb.Maintenance.Node.StorageNode',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=561,
  serialized_end=574,
)

_NODE_DYNAMICNODE = _descriptor.Descriptor(
  name='DynamicNode',
  full_name='Ydb.Maintenance.Node.DynamicNode',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tenant', full_name='Ydb.Maintenance.Node.DynamicNode.tenant', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=576,
  serialized_end=605,
)

_NODE = _descriptor.Descriptor(
  name='Node',
  full_name='Ydb.Maintenance.Node',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='node_id', full_name='Ydb.Maintenance.Node.node_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='host', full_name='Ydb.Maintenance.Node.host', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='port', full_name='Ydb.Maintenance.Node.port', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='location', full_name='Ydb.Maintenance.Node.location', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state', full_name='Ydb.Maintenance.Node.state', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='storage', full_name='Ydb.Maintenance.Node.storage', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dynamic', full_name='Ydb.Maintenance.Node.dynamic', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_time', full_name='Ydb.Maintenance.Node.start_time', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='Ydb.Maintenance.Node.version', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_NODE_STORAGENODE, _NODE_DYNAMICNODE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='type', full_name='Ydb.Maintenance.Node.type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=245,
  serialized_end=613,
)


_LISTCLUSTERNODESREQUEST = _descriptor.Descriptor(
  name='ListClusterNodesRequest',
  full_name='Ydb.Maintenance.ListClusterNodesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='Ydb.Maintenance.ListClusterNodesRequest.operation_params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=615,
  serialized_end=699,
)


_LISTCLUSTERNODESRESULT = _descriptor.Descriptor(
  name='ListClusterNodesResult',
  full_name='Ydb.Maintenance.ListClusterNodesResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='nodes', full_name='Ydb.Maintenance.ListClusterNodesResult.nodes', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=701,
  serialized_end=763,
)


_LISTCLUSTERNODESRESPONSE = _descriptor.Descriptor(
  name='ListClusterNodesResponse',
  full_name='Ydb.Maintenance.ListClusterNodesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='Ydb.Maintenance.ListClusterNodesResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=765,
  serialized_end=837,
)


_MAINTENANCETASKOPTIONS = _descriptor.Descriptor(
  name='MaintenanceTaskOptions',
  full_name='Ydb.Maintenance.MaintenanceTaskOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='task_uid', full_name='Ydb.Maintenance.MaintenanceTaskOptions.task_uid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\003\030\200\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='Ydb.Maintenance.MaintenanceTaskOptions.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\003\030\200\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='availability_mode', full_name='Ydb.Maintenance.MaintenanceTaskOptions.availability_mode', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dry_run', full_name='Ydb.Maintenance.MaintenanceTaskOptions.dry_run', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='priority', full_name='Ydb.Maintenance.MaintenanceTaskOptions.priority', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\262\346*\013[-100; 100]', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=840,
  serialized_end=1035,
)


_ACTIONSCOPE = _descriptor.Descriptor(
  name='ActionScope',
  full_name='Ydb.Maintenance.ActionScope',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='node_id', full_name='Ydb.Maintenance.ActionScope.node_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='host', full_name='Ydb.Maintenance.ActionScope.host', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\003\030\377\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='scope', full_name='Ydb.Maintenance.ActionScope.scope',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1037,
  serialized_end=1103,
)


_LOCKACTION = _descriptor.Descriptor(
  name='LockAction',
  full_name='Ydb.Maintenance.LockAction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='scope', full_name='Ydb.Maintenance.LockAction.scope', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='duration', full_name='Ydb.Maintenance.LockAction.duration', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1105,
  serialized_end=1207,
)


_ACTION = _descriptor.Descriptor(
  name='Action',
  full_name='Ydb.Maintenance.Action',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='lock_action', full_name='Ydb.Maintenance.Action.lock_action', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='action', full_name='Ydb.Maintenance.Action.action',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1209,
  serialized_end=1279,
)


_ACTIONGROUP = _descriptor.Descriptor(
  name='ActionGroup',
  full_name='Ydb.Maintenance.ActionGroup',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='actions', full_name='Ydb.Maintenance.ActionGroup.actions', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\232\346*\002(\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1281,
  serialized_end=1344,
)


_CREATEMAINTENANCETASKREQUEST = _descriptor.Descriptor(
  name='CreateMaintenanceTaskRequest',
  full_name='Ydb.Maintenance.CreateMaintenanceTaskRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='Ydb.Maintenance.CreateMaintenanceTaskRequest.operation_params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='task_options', full_name='Ydb.Maintenance.CreateMaintenanceTaskRequest.task_options', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='action_groups', full_name='Ydb.Maintenance.CreateMaintenanceTaskRequest.action_groups', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\232\346*\002(\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1347,
  serialized_end=1560,
)


_REFRESHMAINTENANCETASKREQUEST = _descriptor.Descriptor(
  name='RefreshMaintenanceTaskRequest',
  full_name='Ydb.Maintenance.RefreshMaintenanceTaskRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='Ydb.Maintenance.RefreshMaintenanceTaskRequest.operation_params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='task_uid', full_name='Ydb.Maintenance.RefreshMaintenanceTaskRequest.task_uid', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\003\030\200\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1562,
  serialized_end=1679,
)


_ACTIONUID = _descriptor.Descriptor(
  name='ActionUid',
  full_name='Ydb.Maintenance.ActionUid',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='task_uid', full_name='Ydb.Maintenance.ActionUid.task_uid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\003\030\200\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='group_id', full_name='Ydb.Maintenance.ActionUid.group_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\003\030\200\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='action_id', full_name='Ydb.Maintenance.ActionUid.action_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\003\030\200\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1681,
  serialized_end=1774,
)


_ACTIONSTATE = _descriptor.Descriptor(
  name='ActionState',
  full_name='Ydb.Maintenance.ActionState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='action', full_name='Ydb.Maintenance.ActionState.action', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='action_uid', full_name='Ydb.Maintenance.ActionState.action_uid', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='Ydb.Maintenance.ActionState.status', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reason', full_name='Ydb.Maintenance.ActionState.reason', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reason_details', full_name='Ydb.Maintenance.ActionState.reason_details', index=4,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deadline', full_name='Ydb.Maintenance.ActionState.deadline', index=5,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _ACTIONSTATE_ACTIONSTATUS,
    _ACTIONSTATE_ACTIONREASON,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1777,
  serialized_end=2560,
)


_ACTIONGROUPSTATES = _descriptor.Descriptor(
  name='ActionGroupStates',
  full_name='Ydb.Maintenance.ActionGroupStates',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='action_states', full_name='Ydb.Maintenance.ActionGroupStates.action_states', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2562,
  serialized_end=2634,
)


_MAINTENANCETASKRESULT = _descriptor.Descriptor(
  name='MaintenanceTaskResult',
  full_name='Ydb.Maintenance.MaintenanceTaskResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='task_uid', full_name='Ydb.Maintenance.MaintenanceTaskResult.task_uid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='action_group_states', full_name='Ydb.Maintenance.MaintenanceTaskResult.action_group_states', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='retry_after', full_name='Ydb.Maintenance.MaintenanceTaskResult.retry_after', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_retry_after', full_name='Ydb.Maintenance.MaintenanceTaskResult._retry_after',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=2637,
  serialized_end=2813,
)


_MAINTENANCETASKRESPONSE = _descriptor.Descriptor(
  name='MaintenanceTaskResponse',
  full_name='Ydb.Maintenance.MaintenanceTaskResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='Ydb.Maintenance.MaintenanceTaskResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2815,
  serialized_end=2886,
)


_GETMAINTENANCETASKREQUEST = _descriptor.Descriptor(
  name='GetMaintenanceTaskRequest',
  full_name='Ydb.Maintenance.GetMaintenanceTaskRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='Ydb.Maintenance.GetMaintenanceTaskRequest.operation_params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='task_uid', full_name='Ydb.Maintenance.GetMaintenanceTaskRequest.task_uid', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\003\030\200\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2888,
  serialized_end=3001,
)


_GETMAINTENANCETASKRESULT = _descriptor.Descriptor(
  name='GetMaintenanceTaskResult',
  full_name='Ydb.Maintenance.GetMaintenanceTaskResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='task_options', full_name='Ydb.Maintenance.GetMaintenanceTaskResult.task_options', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='action_group_states', full_name='Ydb.Maintenance.GetMaintenanceTaskResult.action_group_states', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3004,
  serialized_end=3158,
)


_GETMAINTENANCETASKRESPONSE = _descriptor.Descriptor(
  name='GetMaintenanceTaskResponse',
  full_name='Ydb.Maintenance.GetMaintenanceTaskResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='Ydb.Maintenance.GetMaintenanceTaskResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3160,
  serialized_end=3234,
)


_LISTMAINTENANCETASKSREQUEST = _descriptor.Descriptor(
  name='ListMaintenanceTasksRequest',
  full_name='Ydb.Maintenance.ListMaintenanceTasksRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='Ydb.Maintenance.ListMaintenanceTasksRequest.operation_params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user', full_name='Ydb.Maintenance.ListMaintenanceTasksRequest.user', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_user', full_name='Ydb.Maintenance.ListMaintenanceTasksRequest._user',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=3236,
  serialized_end=3352,
)


_LISTMAINTENANCETASKSRESULT = _descriptor.Descriptor(
  name='ListMaintenanceTasksResult',
  full_name='Ydb.Maintenance.ListMaintenanceTasksResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tasks_uids', full_name='Ydb.Maintenance.ListMaintenanceTasksResult.tasks_uids', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3354,
  serialized_end=3402,
)


_LISTMAINTENANCETASKSRESPONSE = _descriptor.Descriptor(
  name='ListMaintenanceTasksResponse',
  full_name='Ydb.Maintenance.ListMaintenanceTasksResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='Ydb.Maintenance.ListMaintenanceTasksResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3404,
  serialized_end=3480,
)


_DROPMAINTENANCETASKREQUEST = _descriptor.Descriptor(
  name='DropMaintenanceTaskRequest',
  full_name='Ydb.Maintenance.DropMaintenanceTaskRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='Ydb.Maintenance.DropMaintenanceTaskRequest.operation_params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='task_uid', full_name='Ydb.Maintenance.DropMaintenanceTaskRequest.task_uid', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\003\030\200\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3482,
  serialized_end=3596,
)


_MANAGEMAINTENANCETASKRESPONSE = _descriptor.Descriptor(
  name='ManageMaintenanceTaskResponse',
  full_name='Ydb.Maintenance.ManageMaintenanceTaskResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='Ydb.Maintenance.ManageMaintenanceTaskResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3598,
  serialized_end=3675,
)


_COMPLETEACTIONREQUEST = _descriptor.Descriptor(
  name='CompleteActionRequest',
  full_name='Ydb.Maintenance.CompleteActionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='Ydb.Maintenance.CompleteActionRequest.operation_params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='action_uids', full_name='Ydb.Maintenance.CompleteActionRequest.action_uids', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\232\346*\002(\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3678,
  serialized_end=3817,
)


_MANAGEACTIONRESULT_STATUS = _descriptor.Descriptor(
  name='Status',
  full_name='Ydb.Maintenance.ManageActionResult.Status',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='action_uid', full_name='Ydb.Maintenance.ManageActionResult.Status.action_uid', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='Ydb.Maintenance.ManageActionResult.Status.status', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3911,
  serialized_end=4010,
)

_MANAGEACTIONRESULT = _descriptor.Descriptor(
  name='ManageActionResult',
  full_name='Ydb.Maintenance.ManageActionResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='action_statuses', full_name='Ydb.Maintenance.ManageActionResult.action_statuses', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_MANAGEACTIONRESULT_STATUS, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3820,
  serialized_end=4010,
)


_MANAGEACTIONRESPONSE = _descriptor.Descriptor(
  name='ManageActionResponse',
  full_name='Ydb.Maintenance.ManageActionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='Ydb.Maintenance.ManageActionResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4012,
  serialized_end=4080,
)

_NODE_STORAGENODE.containing_type = _NODE
_NODE_DYNAMICNODE.containing_type = _NODE
_NODE.fields_by_name['location'].message_type = protos_dot_ydb__discovery__pb2._NODELOCATION
_NODE.fields_by_name['state'].enum_type = _ITEMSTATE
_NODE.fields_by_name['storage'].message_type = _NODE_STORAGENODE
_NODE.fields_by_name['dynamic'].message_type = _NODE_DYNAMICNODE
_NODE.fields_by_name['start_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_NODE.oneofs_by_name['type'].fields.append(
  _NODE.fields_by_name['storage'])
_NODE.fields_by_name['storage'].containing_oneof = _NODE.oneofs_by_name['type']
_NODE.oneofs_by_name['type'].fields.append(
  _NODE.fields_by_name['dynamic'])
_NODE.fields_by_name['dynamic'].containing_oneof = _NODE.oneofs_by_name['type']
_LISTCLUSTERNODESREQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_LISTCLUSTERNODESRESULT.fields_by_name['nodes'].message_type = _NODE
_LISTCLUSTERNODESRESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
_MAINTENANCETASKOPTIONS.fields_by_name['availability_mode'].enum_type = _AVAILABILITYMODE
_ACTIONSCOPE.oneofs_by_name['scope'].fields.append(
  _ACTIONSCOPE.fields_by_name['node_id'])
_ACTIONSCOPE.fields_by_name['node_id'].containing_oneof = _ACTIONSCOPE.oneofs_by_name['scope']
_ACTIONSCOPE.oneofs_by_name['scope'].fields.append(
  _ACTIONSCOPE.fields_by_name['host'])
_ACTIONSCOPE.fields_by_name['host'].containing_oneof = _ACTIONSCOPE.oneofs_by_name['scope']
_LOCKACTION.fields_by_name['scope'].message_type = _ACTIONSCOPE
_LOCKACTION.fields_by_name['duration'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_ACTION.fields_by_name['lock_action'].message_type = _LOCKACTION
_ACTION.oneofs_by_name['action'].fields.append(
  _ACTION.fields_by_name['lock_action'])
_ACTION.fields_by_name['lock_action'].containing_oneof = _ACTION.oneofs_by_name['action']
_ACTIONGROUP.fields_by_name['actions'].message_type = _ACTION
_CREATEMAINTENANCETASKREQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_CREATEMAINTENANCETASKREQUEST.fields_by_name['task_options'].message_type = _MAINTENANCETASKOPTIONS
_CREATEMAINTENANCETASKREQUEST.fields_by_name['action_groups'].message_type = _ACTIONGROUP
_REFRESHMAINTENANCETASKREQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_ACTIONSTATE.fields_by_name['action'].message_type = _ACTION
_ACTIONSTATE.fields_by_name['action_uid'].message_type = _ACTIONUID
_ACTIONSTATE.fields_by_name['status'].enum_type = _ACTIONSTATE_ACTIONSTATUS
_ACTIONSTATE.fields_by_name['reason'].enum_type = _ACTIONSTATE_ACTIONREASON
_ACTIONSTATE.fields_by_name['deadline'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_ACTIONSTATE_ACTIONSTATUS.containing_type = _ACTIONSTATE
_ACTIONSTATE_ACTIONREASON.containing_type = _ACTIONSTATE
_ACTIONGROUPSTATES.fields_by_name['action_states'].message_type = _ACTIONSTATE
_MAINTENANCETASKRESULT.fields_by_name['action_group_states'].message_type = _ACTIONGROUPSTATES
_MAINTENANCETASKRESULT.fields_by_name['retry_after'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_MAINTENANCETASKRESULT.oneofs_by_name['_retry_after'].fields.append(
  _MAINTENANCETASKRESULT.fields_by_name['retry_after'])
_MAINTENANCETASKRESULT.fields_by_name['retry_after'].containing_oneof = _MAINTENANCETASKRESULT.oneofs_by_name['_retry_after']
_MAINTENANCETASKRESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
_GETMAINTENANCETASKREQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_GETMAINTENANCETASKRESULT.fields_by_name['task_options'].message_type = _MAINTENANCETASKOPTIONS
_GETMAINTENANCETASKRESULT.fields_by_name['action_group_states'].message_type = _ACTIONGROUPSTATES
_GETMAINTENANCETASKRESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
_LISTMAINTENANCETASKSREQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_LISTMAINTENANCETASKSREQUEST.oneofs_by_name['_user'].fields.append(
  _LISTMAINTENANCETASKSREQUEST.fields_by_name['user'])
_LISTMAINTENANCETASKSREQUEST.fields_by_name['user'].containing_oneof = _LISTMAINTENANCETASKSREQUEST.oneofs_by_name['_user']
_LISTMAINTENANCETASKSRESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
_DROPMAINTENANCETASKREQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_MANAGEMAINTENANCETASKRESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
_COMPLETEACTIONREQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_COMPLETEACTIONREQUEST.fields_by_name['action_uids'].message_type = _ACTIONUID
_MANAGEACTIONRESULT_STATUS.fields_by_name['action_uid'].message_type = _ACTIONUID
_MANAGEACTIONRESULT_STATUS.fields_by_name['status'].enum_type = protos_dot_ydb__status__codes__pb2._STATUSIDS_STATUSCODE
_MANAGEACTIONRESULT_STATUS.containing_type = _MANAGEACTIONRESULT
_MANAGEACTIONRESULT.fields_by_name['action_statuses'].message_type = _MANAGEACTIONRESULT_STATUS
_MANAGEACTIONRESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
DESCRIPTOR.message_types_by_name['Node'] = _NODE
DESCRIPTOR.message_types_by_name['ListClusterNodesRequest'] = _LISTCLUSTERNODESREQUEST
DESCRIPTOR.message_types_by_name['ListClusterNodesResult'] = _LISTCLUSTERNODESRESULT
DESCRIPTOR.message_types_by_name['ListClusterNodesResponse'] = _LISTCLUSTERNODESRESPONSE
DESCRIPTOR.message_types_by_name['MaintenanceTaskOptions'] = _MAINTENANCETASKOPTIONS
DESCRIPTOR.message_types_by_name['ActionScope'] = _ACTIONSCOPE
DESCRIPTOR.message_types_by_name['LockAction'] = _LOCKACTION
DESCRIPTOR.message_types_by_name['Action'] = _ACTION
DESCRIPTOR.message_types_by_name['ActionGroup'] = _ACTIONGROUP
DESCRIPTOR.message_types_by_name['CreateMaintenanceTaskRequest'] = _CREATEMAINTENANCETASKREQUEST
DESCRIPTOR.message_types_by_name['RefreshMaintenanceTaskRequest'] = _REFRESHMAINTENANCETASKREQUEST
DESCRIPTOR.message_types_by_name['ActionUid'] = _ACTIONUID
DESCRIPTOR.message_types_by_name['ActionState'] = _ACTIONSTATE
DESCRIPTOR.message_types_by_name['ActionGroupStates'] = _ACTIONGROUPSTATES
DESCRIPTOR.message_types_by_name['MaintenanceTaskResult'] = _MAINTENANCETASKRESULT
DESCRIPTOR.message_types_by_name['MaintenanceTaskResponse'] = _MAINTENANCETASKRESPONSE
DESCRIPTOR.message_types_by_name['GetMaintenanceTaskRequest'] = _GETMAINTENANCETASKREQUEST
DESCRIPTOR.message_types_by_name['GetMaintenanceTaskResult'] = _GETMAINTENANCETASKRESULT
DESCRIPTOR.message_types_by_name['GetMaintenanceTaskResponse'] = _GETMAINTENANCETASKRESPONSE
DESCRIPTOR.message_types_by_name['ListMaintenanceTasksRequest'] = _LISTMAINTENANCETASKSREQUEST
DESCRIPTOR.message_types_by_name['ListMaintenanceTasksResult'] = _LISTMAINTENANCETASKSRESULT
DESCRIPTOR.message_types_by_name['ListMaintenanceTasksResponse'] = _LISTMAINTENANCETASKSRESPONSE
DESCRIPTOR.message_types_by_name['DropMaintenanceTaskRequest'] = _DROPMAINTENANCETASKREQUEST
DESCRIPTOR.message_types_by_name['ManageMaintenanceTaskResponse'] = _MANAGEMAINTENANCETASKRESPONSE
DESCRIPTOR.message_types_by_name['CompleteActionRequest'] = _COMPLETEACTIONREQUEST
DESCRIPTOR.message_types_by_name['ManageActionResult'] = _MANAGEACTIONRESULT
DESCRIPTOR.message_types_by_name['ManageActionResponse'] = _MANAGEACTIONRESPONSE
DESCRIPTOR.enum_types_by_name['ItemState'] = _ITEMSTATE
DESCRIPTOR.enum_types_by_name['AvailabilityMode'] = _AVAILABILITYMODE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Node = _reflection.GeneratedProtocolMessageType('Node', (_message.Message,), {

  'StorageNode' : _reflection.GeneratedProtocolMessageType('StorageNode', (_message.Message,), {
    'DESCRIPTOR' : _NODE_STORAGENODE,
    '__module__' : 'draft.protos.ydb_maintenance_pb2'
    # @@protoc_insertion_point(class_scope:Ydb.Maintenance.Node.StorageNode)
    })
  ,

  'DynamicNode' : _reflection.GeneratedProtocolMessageType('DynamicNode', (_message.Message,), {
    'DESCRIPTOR' : _NODE_DYNAMICNODE,
    '__module__' : 'draft.protos.ydb_maintenance_pb2'
    # @@protoc_insertion_point(class_scope:Ydb.Maintenance.Node.DynamicNode)
    })
  ,
  'DESCRIPTOR' : _NODE,
  '__module__' : 'draft.protos.ydb_maintenance_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Maintenance.Node)
  })
_sym_db.RegisterMessage(Node)
_sym_db.RegisterMessage(Node.StorageNode)
_sym_db.RegisterMessage(Node.DynamicNode)

ListClusterNodesRequest = _reflection.GeneratedProtocolMessageType('ListClusterNodesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTCLUSTERNODESREQUEST,
  '__module__' : 'draft.protos.ydb_maintenance_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Maintenance.ListClusterNodesRequest)
  })
_sym_db.RegisterMessage(ListClusterNodesRequest)

ListClusterNodesResult = _reflection.GeneratedProtocolMessageType('ListClusterNodesResult', (_message.Message,), {
  'DESCRIPTOR' : _LISTCLUSTERNODESRESULT,
  '__module__' : 'draft.protos.ydb_maintenance_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Maintenance.ListClusterNodesResult)
  })
_sym_db.RegisterMessage(ListClusterNodesResult)

ListClusterNodesResponse = _reflection.GeneratedProtocolMessageType('ListClusterNodesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTCLUSTERNODESRESPONSE,
  '__module__' : 'draft.protos.ydb_maintenance_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Maintenance.ListClusterNodesResponse)
  })
_sym_db.RegisterMessage(ListClusterNodesResponse)

MaintenanceTaskOptions = _reflection.GeneratedProtocolMessageType('MaintenanceTaskOptions', (_message.Message,), {
  'DESCRIPTOR' : _MAINTENANCETASKOPTIONS,
  '__module__' : 'draft.protos.ydb_maintenance_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Maintenance.MaintenanceTaskOptions)
  })
_sym_db.RegisterMessage(MaintenanceTaskOptions)

ActionScope = _reflection.GeneratedProtocolMessageType('ActionScope', (_message.Message,), {
  'DESCRIPTOR' : _ACTIONSCOPE,
  '__module__' : 'draft.protos.ydb_maintenance_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Maintenance.ActionScope)
  })
_sym_db.RegisterMessage(ActionScope)

LockAction = _reflection.GeneratedProtocolMessageType('LockAction', (_message.Message,), {
  'DESCRIPTOR' : _LOCKACTION,
  '__module__' : 'draft.protos.ydb_maintenance_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Maintenance.LockAction)
  })
_sym_db.RegisterMessage(LockAction)

Action = _reflection.GeneratedProtocolMessageType('Action', (_message.Message,), {
  'DESCRIPTOR' : _ACTION,
  '__module__' : 'draft.protos.ydb_maintenance_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Maintenance.Action)
  })
_sym_db.RegisterMessage(Action)

ActionGroup = _reflection.GeneratedProtocolMessageType('ActionGroup', (_message.Message,), {
  'DESCRIPTOR' : _ACTIONGROUP,
  '__module__' : 'draft.protos.ydb_maintenance_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Maintenance.ActionGroup)
  })
_sym_db.RegisterMessage(ActionGroup)

CreateMaintenanceTaskRequest = _reflection.GeneratedProtocolMessageType('CreateMaintenanceTaskRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEMAINTENANCETASKREQUEST,
  '__module__' : 'draft.protos.ydb_maintenance_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Maintenance.CreateMaintenanceTaskRequest)
  })
_sym_db.RegisterMessage(CreateMaintenanceTaskRequest)

RefreshMaintenanceTaskRequest = _reflection.GeneratedProtocolMessageType('RefreshMaintenanceTaskRequest', (_message.Message,), {
  'DESCRIPTOR' : _REFRESHMAINTENANCETASKREQUEST,
  '__module__' : 'draft.protos.ydb_maintenance_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Maintenance.RefreshMaintenanceTaskRequest)
  })
_sym_db.RegisterMessage(RefreshMaintenanceTaskRequest)

ActionUid = _reflection.GeneratedProtocolMessageType('ActionUid', (_message.Message,), {
  'DESCRIPTOR' : _ACTIONUID,
  '__module__' : 'draft.protos.ydb_maintenance_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Maintenance.ActionUid)
  })
_sym_db.RegisterMessage(ActionUid)

ActionState = _reflection.GeneratedProtocolMessageType('ActionState', (_message.Message,), {
  'DESCRIPTOR' : _ACTIONSTATE,
  '__module__' : 'draft.protos.ydb_maintenance_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Maintenance.ActionState)
  })
_sym_db.RegisterMessage(ActionState)

ActionGroupStates = _reflection.GeneratedProtocolMessageType('ActionGroupStates', (_message.Message,), {
  'DESCRIPTOR' : _ACTIONGROUPSTATES,
  '__module__' : 'draft.protos.ydb_maintenance_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Maintenance.ActionGroupStates)
  })
_sym_db.RegisterMessage(ActionGroupStates)

MaintenanceTaskResult = _reflection.GeneratedProtocolMessageType('MaintenanceTaskResult', (_message.Message,), {
  'DESCRIPTOR' : _MAINTENANCETASKRESULT,
  '__module__' : 'draft.protos.ydb_maintenance_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Maintenance.MaintenanceTaskResult)
  })
_sym_db.RegisterMessage(MaintenanceTaskResult)

MaintenanceTaskResponse = _reflection.GeneratedProtocolMessageType('MaintenanceTaskResponse', (_message.Message,), {
  'DESCRIPTOR' : _MAINTENANCETASKRESPONSE,
  '__module__' : 'draft.protos.ydb_maintenance_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Maintenance.MaintenanceTaskResponse)
  })
_sym_db.RegisterMessage(MaintenanceTaskResponse)

GetMaintenanceTaskRequest = _reflection.GeneratedProtocolMessageType('GetMaintenanceTaskRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETMAINTENANCETASKREQUEST,
  '__module__' : 'draft.protos.ydb_maintenance_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Maintenance.GetMaintenanceTaskRequest)
  })
_sym_db.RegisterMessage(GetMaintenanceTaskRequest)

GetMaintenanceTaskResult = _reflection.GeneratedProtocolMessageType('GetMaintenanceTaskResult', (_message.Message,), {
  'DESCRIPTOR' : _GETMAINTENANCETASKRESULT,
  '__module__' : 'draft.protos.ydb_maintenance_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Maintenance.GetMaintenanceTaskResult)
  })
_sym_db.RegisterMessage(GetMaintenanceTaskResult)

GetMaintenanceTaskResponse = _reflection.GeneratedProtocolMessageType('GetMaintenanceTaskResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETMAINTENANCETASKRESPONSE,
  '__module__' : 'draft.protos.ydb_maintenance_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Maintenance.GetMaintenanceTaskResponse)
  })
_sym_db.RegisterMessage(GetMaintenanceTaskResponse)

ListMaintenanceTasksRequest = _reflection.GeneratedProtocolMessageType('ListMaintenanceTasksRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTMAINTENANCETASKSREQUEST,
  '__module__' : 'draft.protos.ydb_maintenance_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Maintenance.ListMaintenanceTasksRequest)
  })
_sym_db.RegisterMessage(ListMaintenanceTasksRequest)

ListMaintenanceTasksResult = _reflection.GeneratedProtocolMessageType('ListMaintenanceTasksResult', (_message.Message,), {
  'DESCRIPTOR' : _LISTMAINTENANCETASKSRESULT,
  '__module__' : 'draft.protos.ydb_maintenance_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Maintenance.ListMaintenanceTasksResult)
  })
_sym_db.RegisterMessage(ListMaintenanceTasksResult)

ListMaintenanceTasksResponse = _reflection.GeneratedProtocolMessageType('ListMaintenanceTasksResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTMAINTENANCETASKSRESPONSE,
  '__module__' : 'draft.protos.ydb_maintenance_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Maintenance.ListMaintenanceTasksResponse)
  })
_sym_db.RegisterMessage(ListMaintenanceTasksResponse)

DropMaintenanceTaskRequest = _reflection.GeneratedProtocolMessageType('DropMaintenanceTaskRequest', (_message.Message,), {
  'DESCRIPTOR' : _DROPMAINTENANCETASKREQUEST,
  '__module__' : 'draft.protos.ydb_maintenance_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Maintenance.DropMaintenanceTaskRequest)
  })
_sym_db.RegisterMessage(DropMaintenanceTaskRequest)

ManageMaintenanceTaskResponse = _reflection.GeneratedProtocolMessageType('ManageMaintenanceTaskResponse', (_message.Message,), {
  'DESCRIPTOR' : _MANAGEMAINTENANCETASKRESPONSE,
  '__module__' : 'draft.protos.ydb_maintenance_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Maintenance.ManageMaintenanceTaskResponse)
  })
_sym_db.RegisterMessage(ManageMaintenanceTaskResponse)

CompleteActionRequest = _reflection.GeneratedProtocolMessageType('CompleteActionRequest', (_message.Message,), {
  'DESCRIPTOR' : _COMPLETEACTIONREQUEST,
  '__module__' : 'draft.protos.ydb_maintenance_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Maintenance.CompleteActionRequest)
  })
_sym_db.RegisterMessage(CompleteActionRequest)

ManageActionResult = _reflection.GeneratedProtocolMessageType('ManageActionResult', (_message.Message,), {

  'Status' : _reflection.GeneratedProtocolMessageType('Status', (_message.Message,), {
    'DESCRIPTOR' : _MANAGEACTIONRESULT_STATUS,
    '__module__' : 'draft.protos.ydb_maintenance_pb2'
    # @@protoc_insertion_point(class_scope:Ydb.Maintenance.ManageActionResult.Status)
    })
  ,
  'DESCRIPTOR' : _MANAGEACTIONRESULT,
  '__module__' : 'draft.protos.ydb_maintenance_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Maintenance.ManageActionResult)
  })
_sym_db.RegisterMessage(ManageActionResult)
_sym_db.RegisterMessage(ManageActionResult.Status)

ManageActionResponse = _reflection.GeneratedProtocolMessageType('ManageActionResponse', (_message.Message,), {
  'DESCRIPTOR' : _MANAGEACTIONRESPONSE,
  '__module__' : 'draft.protos.ydb_maintenance_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Maintenance.ManageActionResponse)
  })
_sym_db.RegisterMessage(ManageActionResponse)


DESCRIPTOR._options = None
_MAINTENANCETASKOPTIONS.fields_by_name['task_uid']._options = None
_MAINTENANCETASKOPTIONS.fields_by_name['description']._options = None
_MAINTENANCETASKOPTIONS.fields_by_name['priority']._options = None
_ACTIONSCOPE.fields_by_name['host']._options = None
_ACTIONGROUP.fields_by_name['actions']._options = None
_CREATEMAINTENANCETASKREQUEST.fields_by_name['action_groups']._options = None
_REFRESHMAINTENANCETASKREQUEST.fields_by_name['task_uid']._options = None
_ACTIONUID.fields_by_name['task_uid']._options = None
_ACTIONUID.fields_by_name['group_id']._options = None
_ACTIONUID.fields_by_name['action_id']._options = None
_GETMAINTENANCETASKREQUEST.fields_by_name['task_uid']._options = None
_DROPMAINTENANCETASKREQUEST.fields_by_name['task_uid']._options = None
_COMPLETEACTIONREQUEST.fields_by_name['action_uids']._options = None
# @@protoc_insertion_point(module_scope)



import asyncio
import json

from typing import (
    Optional,
    Dict,
    Any,
    Union,
)

from .base import AsyncResponseContextIterator
from .transaction import QueryTxContext
from .. import _utilities
from ... import issues
from ...settings import BaseRequestSettings
from ..._grpc.grpcwrapper import common_utils
from ..._grpc.grpcwrapper import ydb_query_public_types as _ydb_query_public

from ...query import base
from ...query.session import BaseQuerySession

from ..._constants import DEFAULT_INITIAL_RESPONSE_TIMEOUT

import logging

logger = logging.getLogger(__name__)


class QuerySession(BaseQuerySession):
    """Session object for Query Service. It is not recommended to control
    session's lifecycle manually - use a QuerySessionPool is always a better choise.
    """

    _loop: asyncio.AbstractEventLoop
    _status_stream: _utilities.AsyncResponseIterator = None

    def __init__(
        self,
        driver: common_utils.SupportedDriverType,
        settings: Optional[base.QueryClientSettings] = None,
        loop: asyncio.AbstractEventLoop = None,
    ):
        super(QuerySession, self).__init__(driver, settings)
        self._loop = loop if loop is not None else asyncio.get_running_loop()

    async def _attach(self) -> None:
        self._stream = await self._attach_call()
        self._status_stream = _utilities.AsyncResponseIterator(
            self._stream,
            lambda response: common_utils.ServerStatus.from_proto(response),
        )

        try:
            first_response = await _utilities.get_first_message_with_timeout(
                self._status_stream,
                DEFAULT_INITIAL_RESPONSE_TIMEOUT,
            )
            issues._process_response(first_response)
        except Exception as e:
            self._invalidate()
            raise e

        self._loop.create_task(self._check_session_status_loop(), name="check session status task")

    async def _check_session_status_loop(self) -> None:
        try:
            async for status in self._status_stream:
                issues._process_response(status)
            logger.debug("Attach stream closed, session_id: %s", self._session_id)
        except Exception as e:
            logger.debug("Attach stream error: %s, session_id: %s", e, self._session_id)
            self._invalidate()

    async def delete(self, settings: Optional[BaseRequestSettings] = None) -> None:
        """Deletes a Session of Query Service on server side and releases resources.

        :return: None
        """
        if self._closed:
            return

        if self._session_id:
            try:
                await self._delete_call(settings=settings)
            except Exception:
                pass

        self._invalidate()

    async def create(self, settings: Optional[BaseRequestSettings] = None) -> "QuerySession":
        """Creates a Session of Query Service on server side and attaches it.

        :return: QuerySession object.
        """
        if self.is_active:
            return self

        if self._closed:
            raise RuntimeError("Session is already closed")

        await self._create_call(settings=settings)
        await self._attach()

        return self

    def transaction(self, tx_mode=None) -> QueryTxContext:
        self._check_session_ready_to_use()
        tx_mode = tx_mode if tx_mode else _ydb_query_public.QuerySerializableReadWrite()

        return QueryTxContext(
            self._driver,
            self,
            tx_mode,
        )

    async def execute(
        self,
        query: str,
        parameters: dict = None,
        syntax: base.QuerySyntax = None,
        exec_mode: base.QueryExecMode = None,
        concurrent_result_sets: bool = False,
        settings: Optional[BaseRequestSettings] = None,
        *,
        stats_mode: Optional[base.QueryStatsMode] = None,
        schema_inclusion_mode: Optional[base.QuerySchemaInclusionMode] = None,
        result_set_format: Optional[base.QueryResultSetFormat] = None,
        arrow_format_settings: Optional[base.ArrowFormatSettings] = None,
    ) -> AsyncResponseContextIterator:
        """Sends a query to Query Service

        :param query: (YQL or SQL text) to be executed.
        :param syntax: Syntax of the query, which is a one from the following choices:
         1) QuerySyntax.YQL_V1, which is default;
         2) QuerySyntax.PG.
        :param parameters: dict with parameters and YDB types;
        :param concurrent_result_sets: A flag to allow YDB mix parts of different result sets. Default is False;
        :param stats_mode: Mode of query statistics to gather, which is a one from the following choices:
         1) QueryStatsMode:NONE, which is default;
         2) QueryStatsMode.BASIC;
         3) QueryStatsMode.FULL;
         4) QueryStatsMode.PROFILE;
        :param schema_inclusion_mode: Schema inclusion mode for result sets:
         1) QuerySchemaInclusionMode.ALWAYS, which is default;
         2) QuerySchemaInclusionMode.FIRST_ONLY.
        :param result_set_format: Format of the result sets:
         1) QueryResultSetFormat.VALUE, which is default;
         2) QueryResultSetFormat.ARROW.
        :param arrow_format_settings: Settings for Arrow format when result_set_format is ARROW.

        :return: Iterator with result sets
        """
        self._check_session_ready_to_use()

        stream_it = await self._execute_call(
            query=query,
            parameters=parameters,
            commit_tx=True,
            syntax=syntax,
            exec_mode=exec_mode,
            stats_mode=stats_mode,
            schema_inclusion_mode=schema_inclusion_mode,
            result_set_format=result_set_format,
            arrow_format_settings=arrow_format_settings,
            concurrent_result_sets=concurrent_result_sets,
            settings=settings,
        )

        return AsyncResponseContextIterator(
            it=stream_it,
            wrapper=lambda resp: base.wrap_execute_query_response(
                rpc_state=None,
                response_pb=resp,
                session=self,
                settings=self._settings,
            ),
            on_error=self._on_execute_stream_error,
        )

    async def explain(
        self,
        query: str,
        parameters: Optional[dict] = None,
        result_format: base.QueryExplainResultFormat = base.QueryExplainResultFormat.STR,
    ) -> Union[str, Dict[str, Any]]:
        """Explains query result
        :param query: YQL or SQL query.
        :param parameters: dict with parameters and YDB types;
        :param result_format: Return format: string or dict.
        :return: Parsed query plan.
        """

        res = await self.execute(query, parameters, exec_mode=base.QueryExecMode.EXPLAIN)

        # it needs to read result sets for set last_query_stats as sideeffect
        async for _ in res:
            pass

        plan = self.last_query_stats.query_plan

        if result_format == base.QueryExplainResultFormat.DICT:
            plan = json.loads(plan)

        return plan



# -*- coding: utf-8 -*-
# flake8: noqa
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: protos/ydb_federation_discovery.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb._grpc.v3.protos import ydb_operation_pb2 as protos_dot_ydb__operation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='protos/ydb_federation_discovery.proto',
  package='Ydb.FederationDiscovery',
  syntax='proto3',
  serialized_options=b'\n#tech.ydb.proto.federation.discoveryB\031FederationDiscoveryProtosZFgithub.com/ydb-platform/ydb-go-genproto/protos/Ydb_FederationDiscovery\370\001\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n%protos/ydb_federation_discovery.proto\x12\x17Ydb.FederationDiscovery\x1a\x1aprotos/ydb_operation.proto\"\xf9\x01\n\x0c\x44\x61tabaseInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x10\n\x08\x65ndpoint\x18\x04 \x01(\t\x12\x10\n\x08location\x18\x05 \x01(\t\x12<\n\x06status\x18\x06 \x01(\x0e\x32,.Ydb.FederationDiscovery.DatabaseInfo.Status\x12\x0e\n\x06weight\x18\x07 \x01(\x03\"O\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\r\n\tAVAILABLE\x10\x01\x12\r\n\tREAD_ONLY\x10\x02\x12\x0f\n\x0bUNAVAILABLE\x10\x03\" \n\x1eListFederationDatabasesRequest\"O\n\x1fListFederationDatabasesResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x9b\x01\n\x1dListFederationDatabasesResult\x12\x1e\n\x16\x63ontrol_plane_endpoint\x18\x01 \x01(\t\x12\x43\n\x14\x66\x65\x64\x65ration_databases\x18\x02 \x03(\x0b\x32%.Ydb.FederationDiscovery.DatabaseInfo\x12\x15\n\rself_location\x18\x03 \x01(\tB\x8b\x01\n#tech.ydb.proto.federation.discoveryB\x19\x46\x65\x64\x65rationDiscoveryProtosZFgithub.com/ydb-platform/ydb-go-genproto/protos/Ydb_FederationDiscovery\xf8\x01\x01\x62\x06proto3'
  ,
  dependencies=[protos_dot_ydb__operation__pb2.DESCRIPTOR,])



_DATABASEINFO_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='Ydb.FederationDiscovery.DatabaseInfo.Status',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STATUS_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='AVAILABLE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='READ_ONLY', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNAVAILABLE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=265,
  serialized_end=344,
)
_sym_db.RegisterEnumDescriptor(_DATABASEINFO_STATUS)


_DATABASEINFO = _descriptor.Descriptor(
  name='DatabaseInfo',
  full_name='Ydb.FederationDiscovery.DatabaseInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='Ydb.FederationDiscovery.DatabaseInfo.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path', full_name='Ydb.FederationDiscovery.DatabaseInfo.path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='id', full_name='Ydb.FederationDiscovery.DatabaseInfo.id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='endpoint', full_name='Ydb.FederationDiscovery.DatabaseInfo.endpoint', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='location', full_name='Ydb.FederationDiscovery.DatabaseInfo.location', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='Ydb.FederationDiscovery.DatabaseInfo.status', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='weight', full_name='Ydb.FederationDiscovery.DatabaseInfo.weight', index=6,
      number=7, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _DATABASEINFO_STATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=95,
  serialized_end=344,
)


_LISTFEDERATIONDATABASESREQUEST = _descriptor.Descriptor(
  name='ListFederationDatabasesRequest',
  full_name='Ydb.FederationDiscovery.ListFederationDatabasesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=346,
  serialized_end=378,
)


_LISTFEDERATIONDATABASESRESPONSE = _descriptor.Descriptor(
  name='ListFederationDatabasesResponse',
  full_name='Ydb.FederationDiscovery.ListFederationDatabasesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='Ydb.FederationDiscovery.ListFederationDatabasesResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=380,
  serialized_end=459,
)


_LISTFEDERATIONDATABASESRESULT = _descriptor.Descriptor(
  name='ListFederationDatabasesResult',
  full_name='Ydb.FederationDiscovery.ListFederationDatabasesResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='control_plane_endpoint', full_name='Ydb.FederationDiscovery.ListFederationDatabasesResult.control_plane_endpoint', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='federation_databases', full_name='Ydb.FederationDiscovery.ListFederationDatabasesResult.federation_databases', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='self_location', full_name='Ydb.FederationDiscovery.ListFederationDatabasesResult.self_location', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=462,
  serialized_end=617,
)

_DATABASEINFO.fields_by_name['status'].enum_type = _DATABASEINFO_STATUS
_DATABASEINFO_STATUS.containing_type = _DATABASEINFO
_LISTFEDERATIONDATABASESRESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
_LISTFEDERATIONDATABASESRESULT.fields_by_name['federation_databases'].message_type = _DATABASEINFO
DESCRIPTOR.message_types_by_name['DatabaseInfo'] = _DATABASEINFO
DESCRIPTOR.message_types_by_name['ListFederationDatabasesRequest'] = _LISTFEDERATIONDATABASESREQUEST
DESCRIPTOR.message_types_by_name['ListFederationDatabasesResponse'] = _LISTFEDERATIONDATABASESRESPONSE
DESCRIPTOR.message_types_by_name['ListFederationDatabasesResult'] = _LISTFEDERATIONDATABASESRESULT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DatabaseInfo = _reflection.GeneratedProtocolMessageType('DatabaseInfo', (_message.Message,), {
  'DESCRIPTOR' : _DATABASEINFO,
  '__module__' : 'protos.ydb_federation_discovery_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.FederationDiscovery.DatabaseInfo)
  })
_sym_db.RegisterMessage(DatabaseInfo)

ListFederationDatabasesRequest = _reflection.GeneratedProtocolMessageType('ListFederationDatabasesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTFEDERATIONDATABASESREQUEST,
  '__module__' : 'protos.ydb_federation_discovery_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.FederationDiscovery.ListFederationDatabasesRequest)
  })
_sym_db.RegisterMessage(ListFederationDatabasesRequest)

ListFederationDatabasesResponse = _reflection.GeneratedProtocolMessageType('ListFederationDatabasesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTFEDERATIONDATABASESRESPONSE,
  '__module__' : 'protos.ydb_federation_discovery_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.FederationDiscovery.ListFederationDatabasesResponse)
  })
_sym_db.RegisterMessage(ListFederationDatabasesResponse)

ListFederationDatabasesResult = _reflection.GeneratedProtocolMessageType('ListFederationDatabasesResult', (_message.Message,), {
  'DESCRIPTOR' : _LISTFEDERATIONDATABASESRESULT,
  '__module__' : 'protos.ydb_federation_discovery_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.FederationDiscovery.ListFederationDatabasesResult)
  })
_sym_db.RegisterMessage(ListFederationDatabasesResult)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
import ydb
import pytest


@pytest.mark.tls
def test_connect_secure(secure_endpoint, database):
    with ydb.Driver(
        endpoint="grpcs://localhost:2135",
        database="/local",
        root_certificates=ydb.load_ydb_root_certificate(),
    ) as driver:
        driver.wait(timeout=10)
        driver.scheme_client.make_directory("/local/test")
        driver.scheme_client.remove_directory("/local/test")



# -*- coding: utf-8 -*-
# flake8: noqa
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: draft/protos/ydb_object_storage.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'draft/protos/ydb_object_storage.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb._grpc.v6.protos import ydb_issue_message_pb2 as protos_dot_ydb__issue__message__pb2
from ydb._grpc.v6.protos import ydb_value_pb2 as protos_dot_ydb__value__pb2
from ydb._grpc.v6.protos import ydb_status_codes_pb2 as protos_dot_ydb__status__codes__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%draft/protos/ydb_object_storage.proto\x12\x11Ydb.ObjectStorage\x1a\x1eprotos/ydb_issue_message.proto\x1a\x16protos/ydb_value.proto\x1a\x1dprotos/ydb_status_codes.proto\"\xd6\x02\n\x0eListingRequest\x12\x12\n\ntable_name\x18\x01 \x01(\t\x12#\n\nkey_prefix\x18\x02 \x01(\x0b\x32\x0f.Ydb.TypedValue\x12\x1a\n\x12path_column_prefix\x18\x03 \x01(\t\x12\x1d\n\x15path_column_delimiter\x18\x04 \x01(\t\x12\x1a\n\x12\x63ontinuation_token\x18\x05 \x01(\x0c\x12/\n\x16start_after_key_suffix\x18\x06 \x01(\x0b\x32\x0f.Ydb.TypedValue\x12\x10\n\x08max_keys\x18\x07 \x01(\x05\x12\x19\n\x11\x63olumns_to_return\x18\x08 \x03(\t\x12(\n\x0fmatching_filter\x18\n \x01(\x0b\x32\x0f.Ydb.TypedValue\"&\n\nEMatchType\x12\t\n\x05\x45QUAL\x10\x00\x12\r\n\tNOT_EQUAL\x10\x01J\x04\x08\t\x10\n\"\xd7\x01\n\x0fListingResponse\x12)\n\x06status\x18\x01 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06issues\x18\x02 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\x12\x17\n\x0f\x63ommon_prefixes\x18\x03 \x03(\t\x12 \n\x08\x63ontents\x18\x04 \x01(\x0b\x32\x0e.Ydb.ResultSet\x12\x14\n\x0cis_truncated\x18\x05 \x01(\x08\x12\x1f\n\x17next_continuation_token\x18\x06 \x01(\x0c\x42p\n#tech.ydb.proto.draft.object_storageZFgithub.com/ydb-platform/ydb-go-genproto/draft/protos/Ydb_ObjectStorage\xf8\x01\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'draft.protos.ydb_object_storage_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n#tech.ydb.proto.draft.object_storageZFgithub.com/ydb-platform/ydb-go-genproto/draft/protos/Ydb_ObjectStorage\370\001\001'
  _globals['_LISTINGREQUEST']._serialized_start=148
  _globals['_LISTINGREQUEST']._serialized_end=490
  _globals['_LISTINGREQUEST_EMATCHTYPE']._serialized_start=446
  _globals['_LISTINGREQUEST_EMATCHTYPE']._serialized_end=484
  _globals['_LISTINGRESPONSE']._serialized_start=493
  _globals['_LISTINGRESPONSE']._serialized_end=708
# @@protoc_insertion_point(module_scope)



import datetime

from google.protobuf.json_format import MessageToDict

from ydb._grpc.grpcwrapper.ydb_topic import OffsetsRange
from .ydb_topic import AlterTopicRequest
from .ydb_topic_public_types import (
    AlterTopicRequestParams,
    PublicAlterConsumer,
    PublicAlterAutoPartitioningSettings,
    PublicAutoPartitioningStrategy,
    PublicConsumer,
    PublicCodec,
)


def test_offsets_range_intersected():
    # not intersected
    for test in [(0, 1, 1, 2), (1, 2, 3, 5)]:
        assert not OffsetsRange(test[0], test[1]).is_intersected_with(OffsetsRange(test[2], test[3]))
        assert not OffsetsRange(test[2], test[3]).is_intersected_with(OffsetsRange(test[0], test[1]))

    # intersected
    for test in [
        (1, 2, 1, 2),
        (1, 10, 1, 2),
        (1, 10, 2, 3),
        (1, 10, 5, 15),
        (10, 20, 5, 15),
    ]:
        assert OffsetsRange(test[0], test[1]).is_intersected_with(OffsetsRange(test[2], test[3]))
        assert OffsetsRange(test[2], test[3]).is_intersected_with(OffsetsRange(test[0], test[1]))


def test_alter_topic_request_from_public_to_proto():
    # Specify all fields with all possible input ways
    params = {
        "path": "topic_name",
        "add_consumers": [
            "new_consumer_1",
            PublicConsumer("new_consumer_2"),
        ],
        "alter_consumers": [
            "old_consumer_1",
            PublicAlterConsumer("old_consumer_2"),
        ],
        "drop_consumers": ["redundant_consumer"],
        "set_retention_period": datetime.timedelta(weeks=4),
        "set_retention_storage_mb": 4,
        "set_supported_codecs": [1, PublicCodec(2)],
        "set_partition_write_burst_bytes": 8,
        "set_partition_write_speed_bytes_per_second": 15,
        "alter_attributes": {"key": "value"},
        "set_metering_mode": 1,
        "set_min_active_partitions": 2,
        "set_max_active_partitions": 8,
        "set_partition_count_limit": 10,
        "alter_auto_partitioning_settings": PublicAlterAutoPartitioningSettings(
            set_strategy=PublicAutoPartitioningStrategy.DISABLED,
        ),
    }

    params_public = AlterTopicRequestParams(**params)
    request = AlterTopicRequest.from_public(params_public)
    request_proto = request.to_proto()

    msg_dict = MessageToDict(request_proto, preserving_proto_field_name=True)

    expected_dict = {
        "path": "topic_name",
        "alter_partitioning_settings": {
            "set_min_active_partitions": "2",
            "set_max_active_partitions": "8",
            "set_partition_count_limit": "10",
            "alter_auto_partitioning_settings": {
                "set_strategy": "AUTO_PARTITIONING_STRATEGY_DISABLED",
                "set_partition_write_speed": {},
            },
        },
        "set_retention_period": "2419200s",
        "set_retention_storage_mb": "4",
        "set_supported_codecs": {"codecs": [1, 2]},
        "set_partition_write_speed_bytes_per_second": "15",
        "set_partition_write_burst_bytes": "8",
        "alter_attributes": {"key": "value"},
        "add_consumers": [
            {"name": "new_consumer_1", "supported_codecs": {}},
            {"name": "new_consumer_2", "supported_codecs": {}},
        ],
        "drop_consumers": ["redundant_consumer"],
        "alter_consumers": [
            {"name": "old_consumer_1"},
            {"name": "old_consumer_2"},
        ],
        "set_metering_mode": "METERING_MODE_RESERVED_CAPACITY",
    }

    assert msg_dict == expected_dict
